Struct
QmiMessageQosBindMuxDataPortInput
since: 1.37
Description [src]
struct QmiMessageQosBindMuxDataPortInput {
/* No available fields */
}
The QmiMessageQosBindMuxDataPortInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Constructors
qmi_message_qos_bind_mux_data_port_input_new
Allocates a new QmiMessageQosBindMuxDataPortInput.
since: 1.37
Instance methods
qmi_message_qos_bind_mux_data_port_input_get_direction
Get the ‘Direction’ field from self.
since: 1.37
qmi_message_qos_bind_mux_data_port_input_get_endpoint
Get the ‘Endpoint’ field from self.
since: 1.37
qmi_message_qos_bind_mux_data_port_input_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_message_qos_bind_mux_data_port_input_set_direction
Set the ‘Direction’ field in the message.
since: 1.37
qmi_message_qos_bind_mux_data_port_input_set_endpoint
Set the ‘Endpoint’ field in the message.
since: 1.37
qmi_message_qos_bind_mux_data_port_input_set_mux_id
Set the ‘Mux Id’ field in the message.
since: 1.37
qmi_message_qos_bind_mux_data_port_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37